"""Input widgets - text areas, autocomplete, search."""

from claudechic.widgets.input.autocomplete import TextAreaAutoComplete
from claudechic.widgets.input.history_search import HistorySearch

__all__ = [
    "TextAreaAutoComplete",
    "HistorySearch",
]
