"""Primitive building-block widgets."""

from claudechic.widgets.primitives.button import Button
from claudechic.widgets.primitives.collapsible import QuietCollapsible
from claudechic.widgets.primitives.scroll import AutoHideScroll
from claudechic.widgets.primitives.spinner import Spinner

__all__ = [
    "Button",
    "QuietCollapsible",
    "AutoHideScroll",
    "Spinner",
]
